<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Department;
use App\Models\Province;
use Illuminate\Http\Request;

class DepartmentController extends Controller
{
    public function index()
    {
        $departments = Department::all();

        return view('admin.department.index', compact('departments'));
    }

    public function deleted()
    {
        $departments = Department::onlyTrashed() ->get();

        return view('admin.department.deleted', compact('departments'));
    }

    public function create()
    {
        $provinces = Province::all();
        
        return view('admin.department.create', compact('provinces'));
    }

    public function store(Request $request) 
    {
        Department::create([
            "name" => $request->name,
            "description" => $request->description,
            "province_id" => $request->province,
        ]);

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.departments.index');
    }

    public function show($id)
    {
        $department = Department::where('_id', $id) ->first();

        return view('admin.department.show', compact('department'));
    }

    public function edit($id)
    {
        $department = Department::where('_id', $id) ->first();
        $provinces = Province::all();

        return view('admin.department.edit', compact('department', 'provinces'));
    }

    public function update(Request $request, $id)
    {
        $department = Department::where('_id', $id) ->first();
        
        $department ->name = $request->name;
        $department ->description = $request->description;
        $department ->province_id = $request->province;

        $department ->save();

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $department = Department::where('_id', $id) ->first();
        $department ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->route('app.admin.departments.deleted');
    }

    public function restore($id)
    {
        $department = Department::withTrashed() ->where('_id', $id)->first();
        $department ->restore();

        notiflash_toast("success", "Données restaurée(s) avec succès");

        return redirect() ->route('app.admin.departments.index');
    }

    public function remove($id)
    {
        $department = Department::withTrashed() ->where('_id', $id)->first();
        $department ->forceDelete();

        notiflash_toast("success", "Données supprimée(s) définitivement avec succès");

        return redirect() ->route('app.admin.departments.deleted');
    }
}
