<?php

namespace App\Http\Controllers\Admin;

use App\Models\Department;
use App\Models\District;
use Illuminate\Http\Request;
use Illuminate\Routing\Controller;

class DistrictController extends Controller
{
    public function index()
    {
        $districts = District::all();

        return view('admin.district.index', compact('districts'));
    }

    public function deleted()
    {
        $districts = District::onlyTrashed() ->get();

        return view('admin.district.deleted', compact('districts'));
    }

    public function create()
    {
        $departments = Department::all();
        
        return view('admin.district.create', compact('departments'));
    }

    public function store(Request $request) 
    {
        District::create([
            "name" => $request->name,
            "description" => $request->description,
            "department_id" => $request->department,
        ]);

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.districts.index');
    }

    public function show($id)
    {
        $district = District::where('_id', $id) ->first();

        return view('admin.district.show', compact('district'));
    }

    public function edit($id)
    {
        $district = District::where('_id', $id) ->first();
        $departments = Department::all();

        return view('admin.district.edit', compact('district', 'departments'));
    }

    public function update(Request $request, $id)
    {
        $district = District::where('_id', $id) ->first();
        
        $district ->name = $request->name;
        $district ->description = $request->description;
        $district ->department_id = $request->department;

        $district ->save();

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $district = District::where('_id', $id) ->first();
        $district ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->route('app.admin.districts.deleted');
    }

    public function restore($id)
    {
        $district = District::withTrashed() ->where('_id', $id)->first();
        $district ->restore();

        notiflash_toast("success", "Données restaurée(s) avec succès");

        return redirect() ->route('app.admin.districts.index');
    }

    public function remove($id)
    {
        $district = District::withTrashed() ->where('_id', $id)->first();
        $district ->forceDelete();

        notiflash_toast("success", "Données supprimée(s) définitivement avec succès");

        return redirect() ->route('app.admin.districts.deleted');
    }
}
