<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Province;
use Illuminate\Http\Request;

class ProvinceController extends Controller
{
    public function index()
    {
        $provinces = Province::all();

        return view('admin.province.index', compact('provinces'));
    }

    public function deleted()
    {
        $provinces = Province::onlyTrashed() ->get();

        return view('admin.province.deleted', compact('provinces'));
    }

    public function create()
    {
        return view('admin.province.create');
    }

    public function store(Request $request) 
    {
        Province::create([
            "name" => $request->name,
            "description" => $request->description,
        ]); 

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.provinces.index');
    }

    public function show($id)
    {
        $province = Province::where('_id', $id) ->first();

        return view('admin.province.show', compact('province'));
    }

    public function edit($id)
    {
        $province = Province::where('_id', $id) ->first();

        return view('admin.province.edit', compact('province'));
    }

    public function update(Request $request, $id)
    {
        $province = Province::where('_id', $id) ->first();
        
        $province ->name = $request->name;
        $province ->description = $request->description;

        $province ->save();

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $province = Province::where('_id', $id) ->first();
        $province ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->route('app.admin.provinces.deleted');
    }

    public function restore($id)
    {
        $province = Province::withTrashed() ->where('_id', $id)->first();
        $province ->restore();

        notiflash_toast("success", "Données restaurée(s) avec succès");

        return redirect() ->route('app.admin.provinces.index');
    }

    public function remove($id)
    {
        $province = Province::withTrashed() ->where('_id', $id)->first();
        $province ->forceDelete();

        notiflash_toast("success", "Données supprimée(s) définitivement avec succès");

        return redirect() ->route('app.admin.provinces.deleted');
    }
}
