<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Permission;
use App\Models\Role;
use Illuminate\Http\Request;

class RoleController extends Controller
{
    public function index()
    {
        $roles = Role::all();

        return view('admin.role.index', compact('roles'));
    }

    public function deleted()
    {
        $roles = Role::onlyTrashed() ->get();

        return view('admin.role.deleted', compact('roles'));
    }

    public function create()
    {
        return view('admin.role.create');
    }

    public function store(Request $request) 
    {
        Role::create([
            "name" => $request->name,
            "display_name" => $request->display_name,
            "description" => $request->description,
        ]);

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.roles.index');
    }

    public function show($id)
    {
        $role = Role::where('_id', $id) ->first();

        return view('admin.role.show', compact('role'));
    }

    public function edit($id)
    {
        $role = Role::where('_id', $id) ->first();
        $permissions = Permission::all();
        $role_permissions = $role->permissions()->get()->pluck('id')->toArray();

        return view('admin.role.edit', compact('role', 'permissions', 'role_permissions'));
    }

    public function update(Request $request, $id)
    {
        $role = Role::where('_id', $id) ->first();
        
        $role ->name = $request->name;
        $role ->display_name = $request->display_name;
        $role ->description = $request->description;

        $role ->save();

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $role = Role::where('_id', $id) ->first();
        $role ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->back();
    }
}
