<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Role;
use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    public function index()
    {
        $users = User::all();

        return view('admin.user.index', compact('users'));
    }

    public function deleted()
    {
        $users = User::onlyTrashed();

        return view('admin.user.index', compact('users'));
    }

    public function create()
    {
        $roles = Role::all();
        
        return view('admin.user.create', compact('roles'));
    }

    public function store(Request $request) 
    {
        $user = User::create([
            "name" => $request->name,
            "email" => $request->email,
            "is_admin" => 1,
            "password" => bcrypt("password"),
        ]);

        $user->syncRoles([$request->role]);

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.users.index');
    }

    public function show($id)
    {
        $user = User::where('_id', $id) ->first();
        $procedures = $user ->orientations;

        return view('admin.user.show', compact('user', 'procedures'));
    }

    public function edit($id)
    {
        $user = User::where('_id', $id) ->first();
        $roles = Role::all();

        return view('admin.user.edit', compact('user', 'roles'));
    }

    public function update(Request $request, $id)
    {
        $user = User::where('_id', $id) ->first();
        
        $user ->name = $request->name;
        $user ->email = $request->email;

        $user ->save();

        $user->syncRoles([$request->role]);

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $user = User::where('_id', $id) ->first();
        $user ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->back();
    }

    public function restore($id)
    {
        $user = User::withTrashed() ->where('_id', $id);
        $user ->restore();

        notiflash_toast("success", "Données restaurée(s) avec succès");

        return redirect() ->back();
    }

    public function remove($id)
    {
        $user = User::withTrashed() ->where('_id', $id);
        $user ->forceDelete();

        notiflash_toast("success", "Données supprimée(s) définitivement avec succès");

        return redirect() ->back();
    }
}
