<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\District;
use App\Models\VotingCenter;
use Illuminate\Http\Request;

class VotingCenterController extends Controller
{
    public function index()
    {
        $votingCenters = VotingCenter::all();

        return view('admin.voting-center.index', compact('votingCenters'));
    }

    public function deleted()
    {
        $votingCenters = VotingCenter::onlyTrashed() ->get();

        return view('admin.voting-center.deleted', compact('votingCenters'));
    }

    public function create()
    {
        $districts = District::all();
        
        return view('admin.voting-center.create', compact('districts'));
    }

    public function store(Request $request) 
    {
        VotingCenter::create([
            "name" => $request->name,
            "description" => $request->description,
            "district_id" => $request->district,
        ]);

        notiflash_toast("success", 'Données créées avec succès.');

        return redirect() ->route('app.admin.voting-centers.index');
    }

    public function show($id)
    {
        $votingCenter = VotingCenter::where('_id', $id) ->first();

        return view('admin.voting-center.show', compact('votingCenter'));
    }

    public function edit($id)
    {
        $votingCenter = VotingCenter::where('_id', $id) ->first();
        $districts = District::all();

        return view('admin.voting-center.edit', compact('votingCenter', 'districts'));
    }

    public function update(Request $request, $id)
    {
        $votingCenter = VotingCenter::where('_id', $id) ->first();
        
        $votingCenter ->name = $request->name;
        $votingCenter ->description = $request->description;
        $votingCenter ->district_id = $request->district;

        $votingCenter ->save();

        notiflash_toast("success", 'Données mises à jour avec succès.');

        return redirect() ->back();
    }
    
    public function delete($id)
    {
        $votingCenter = VotingCenter::where('_id', $id) ->first();
        $votingCenter ->delete();

        notiflash_toast("success", 'Données supprimées avec succès.');

        return redirect() ->route('app.admin.voting-centers.deleted');
    }

    public function restore($id)
    {
        $votingCenter = VotingCenter::withTrashed() ->where('_id', $id)->first();
        $votingCenter ->restore();

        notiflash_toast("success", "Données restaurée(s) avec succès");

        return redirect() ->route('app.admin.voting-centers.index');
    }

    public function remove($id)
    {
        $votingCenter = VotingCenter::withTrashed() ->where('_id', $id)->first();
        $votingCenter ->forceDelete();

        notiflash_toast("success", "Données supprimée(s) définitivement avec succès");

        return redirect() ->route('app.admin.voting-centers.deleted');
    }
}
