<?php

namespace App\Actions\Fortify;
namespace App\Http\Controllers\Admin;

namespace App\Http\Controllers;

use App\Models\Profilsutilisateurs;
use App\Models\Personnels;
use App\Models\Team;
use App\Models\User;
use Illuminate\Support\Facades\DB;
use App\Http\Requests\StoreTparamsRequest;
use App\Http\Requests\UpdateTparamsRequest;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Laravel\Fortify\Contracts\CreatesNewUsers;
use Laravel\Jetstream\Jetstream;

use Illuminate\Http\Request;


use App\Actions\Fortify\PasswordValidationRules;

use Brian2694\Toastr\Facades\Toastr;
class UserController extends Controller
{

    public function index()
    {
    	$donnees['profils'] = Profilsutilisateurs::orderBy('code')->get();
    	$donnees['all_personnels'] = Personnels::orderBy('nom_agent')->get();
    	return view('administration.utilisateurs')->with($donnees);
    }
    public function changermdp()
    {
        Toastr::error("Vous devez modifier votre mot de passe par défaut pour acceder à votre interface.", "Modification du mot de passe");
    	return view('administration.first_connect');
    }

    public function show($id)
    {
        $donnees['user'] = User::findOrFail($id);

    	$donnees['profils'] = Profilsutilisateurs::orderBy('code')->get();
    	$donnees['all_personnels'] = Personnels::orderBy('nom_agent')->get();

    	return view('administration.details_user')->with($donnees);
    }
    public function store(Request $request)
    {
        $personnel = Personnels::findOrFail($request->personnel_id);
        $nom = $personnel->noms;

        User::create([
            'name' => $nom,
            'email' => $request->email,
            'personnel_id' => $request->personnel_id,
            'profilsutilisateur_id' => $request->profilsutilisateur_id,
            'password' => Hash::make($request->password),
        ]);

        Toastr::success("Type de Donnée ajouté avec success", "Type de Donnée");
        return back();
    }
    public function modif_default_mdp(Request $request){
        $table = User::where('id', $request->id);
        if($request->password===$request->password_confirmation){
            $table->update([
                'first_connect' => 0,
                'password' => Hash::make($request->password)
            ]);

            Toastr::success("Mot de passe modifié avec success, connectez-vous à présent avec votre nouveau mot de passe.", "Mot de Passe Modifié");

            return redirect()->route('dashboard');
        }else{
            Toastr::error("Vos deux mot de passe ne correspondent pas.", "Mot de Passe erroné");
            return back();
        }
    }

    public function modifier_login_user(Request $request){
        $table = User::where('id', $request->id);
        if($request->password===$request->password_confirmation){
            $table->update([
                'first_connect' => 1,
                'email' => $request->email,
                'password' => Hash::make($request->password)
            ]);

            Toastr::success("Mot de passe et login modifiés avec success, connectez-vous à présent avec votre nouveau mot de passe.", "Athentification");
        }else{
            Toastr::error("Vos deux mot de passe ne correspondent pas.", "Athentification");
        }
        return back();
    }
    public function modifier_profil_user(Request $request){
        $table = User::where('id', $request->id);
        $table->update([
            'profilsutilisateur_id' => $request->champ1
        ]);
        Toastr::success("Profil modifié avec success.", "Profil Utilisateur");
        return back();
    }

    public function modifier_nom_user(Request $request){

        if(isset($request->photo) and !empty($request->photo)){
            $photo = $request->photo->store("public/profil_users");
        }else{
            $photo = "starage/profil_users/inconnu.png";
        }
        $table = User::where('id', $request->id);
        $table->update([
            'name' => $request->champ1,
            'profile_photo_path' => $photo,
        ]);
        Toastr::success("Information modifiée avec success.", "Information");
        return back();
    }

    public function reinitialiser(Request $request){
        $table = User::where('id', $request->id);
        $table->update([
            'first_connect' => 1,
            'password' => Hash::make("CNNII2022")
        ]);
        Toastr::success("Mot de passe réinitialisé avec success, connectez-vous à présent avec votre nouveau mot de passe.", "Réinitialisation du Mot de Passe");
        return back();
    }
    public function create(Request $request)
    {
        $personnel = Personnels::findOrFail($request->personnel_id);
        $nom = $personnel->noms;

        Validator::make($request, [
            'name' => ['required', 'string', 'max:255'],
            'personnel_id' => ['required'],
            'profilsutilisateur_id' => ['required'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => $this->passwordRules(),
            'terms' => Jetstream::hasTermsAndPrivacyPolicyFeature() ? ['required', 'accepted'] : '',
        ])->validate();

        return DB::transaction(function () use ($request) {
            $personnel = Personnels::findOrFail($request->personnel_id);
            $nom = $personnel->noms;
            return tap(User::create([
                'name' => $nom,
                'email' => $request->email,
                'personnel_id' => $request->personnel_id,
                'profilsutilisateur_id' => $request->profilsutilisateur_id,
                'password' => Hash::make($request->password),
            ]), function (User $user) {
                $this->createTeam($user);
            });
        });
    }

}
