<?php

namespace App\Models;

use App\Models\Department;
use App\Models\Representative;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;
use Mawuekom\ModelUuid\Utils\GeneratesUuid;

class Province extends Model
{
    // use HasFactory, GeneratesUuid, SoftDeletes;

    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'provinces';

    /**
     * The primary key associated with the table.
     *
     * @var string
     */
    protected $primaryKey = 'id';

    /**
     * Indicates if the model should be timestamped.
     *
     * @var bool
     */
    public $timestamps = true;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'name', 'description',
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [];

    /**
     * The attributes that should be cast to native types.
     *
     * @var array
     */
    protected $casts = [];

    /**
     * The names of the columns that should be used for the UUID.
     *
     * @return array
     */
    public function uuidColumns(): array
    {
        return ['_id'];
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function departments(): HasMany
    {
        return $this ->hasMany(Department::class, 'province_id', 'id');
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function representatives(): HasMany
    {
        return $this ->hasMany(Representative::class, 'province_id', 'id');
    }


    /// 
    public function resultats(): HasMany
    {
        return $this ->hasMany(Resultat::class, 'province_id', 'id');
    }
    public function bureaus(): HasMany
    {
        return $this ->hasMany(Bureau::class, 'bureau_id', 'id');
    }


    public function pourcentage_province($candidat_id){
        $candidat = Params::findOrFail($candidat_id);
        $pourcentage = 0;
        $total_obtenu = $this->resultats()->where('candidat_id', $candidat_id)->sum('vote');
        $total = $this->resultats()->sum('vote');
        $total = ($total==0)?1:$total;
        $pourcentage = round(($total_obtenu*100/$total), 2);
        return $pourcentage;
    }
    
    public function pourcentage($candidat_id){
        $pourcentage = 0;
        $candidat = Params::findOrFail($candidat_id);
        $nomtre_obtenu = $this->resultats()->where('candidat_id', $candidat_id)->sum('vote');
        $exprime = $this->resultats()->sum('vote');
        $exprime = ($exprime==0)?1:$exprime;
        $pourcentage = round(($pourcentage*100/$exprime),2);
        return $pourcentage;

    }
}
